require 'sidekiq_fork'

class ForkWorker
  include Sidekiq::Worker

  sidekiq_options fork: true
end

class NoForkWorker
  include Sidekiq::Worker
end

describe SidekiqFork::ForkMiddleware do

  context 'with forking enabled' do
    let (:worker) { ForkWorker.new }

    it 'runs jobs in a new thread' do
      expect(Process).to receive(:fork).and_yield.and_return(42)
      expect(Process).to receive(:wait).with(42)

      expect { |b| subject.call(worker, nil, nil, &b) }.to yield_with_no_args
    end
  end

  context 'with forking disabled' do
    let (:worker) { NoForkWorker.new }

    it 'does not run jobs in a new thread' do
      expect(Process).to_not receive(:fork)
      expect(Process).to_not receive(:wait)

      expect { |b| subject.call(worker, nil, nil, &b) }.to yield_with_no_args
    end
  end
end
